SecretKey

Struct SecretKey 

pub struct SecretKey { /* private fields */ }
X25519 Diffie-Hellman key exchange private key (RFC 7748).

Generating a key

use crypto::curve25519::x25519::SecretKey;

let alice = SecretKey::generate();
let bob = SecretKey::generate();

Diffie-Hellman key exchange

use crypto::curve25519::x25519::SecretKey;

let alice = SecretKey::generate();
let bob = SecretKey::generate();
let alice_shared = alice.ecdh(&bob.public_key());
let bob_shared = bob.ecdh(&alice.public_key());
assert_eq!(alice_shared, bob_shared);

Conversion from Ed25519

An Ed25519 SecretKey can be converted to an X25519 key via From<&ed25519::SecretKey>.

Security

The shared secret produced by ecdh must not be used directly as an encryption key. Apply a KDF (e.g. HKDF) first.

Implementations

Source

impl SecretKey

pub fn generate() -> SecretKey

pub fn from_bytes(bytes: &[u8; 32]) -> SecretKey

pub fn to_bytes(&self) -> [u8; 32]

pub fn public_key(&self) -> PublicKey

pub fn ecdh(&self, peer: &PublicKey) -> [u8; 32]

Perform a Diffie-Hellman key exchange to derive a shared secret. The shared secret IS NOT SAFE to use directly as an encryption key and an additional key derivation operation must be applied to it.